pub struct BloomFilter { /* private fields */ }
A simple implementation of a Bloom filter backed by BitVec

Implementations

Creates a new BloomFilter (or opens an existing one, if the file already exists) of a given size (in bits) and with a given number of hash functions for each insert (n_hashes). If a filename is not passed, the Bloom filter will be created in memory.

Insert an item into the Bloom filter.

Check if an item is in the Bloom filter already.