Struct mmap_bitvec::BloomFilter
source · pub struct BloomFilter { /* private fields */ }Expand description
A simple implementation of a Bloom filter backed by BitVec
Implementations
sourceimpl BloomFilter
impl BloomFilter
sourcepub fn new<P>(
filename: Option<P>,
bits: usize,
n_hashes: u8
) -> Result<Self, Error>where
P: AsRef<Path>,
pub fn new<P>(
filename: Option<P>,
bits: usize,
n_hashes: u8
) -> Result<Self, Error>where
P: AsRef<Path>,
Creates a new BloomFilter (or opens an existing one, if the file
already exists) of a given size (in bits) and with a given number of
hash functions for each insert (n_hashes). If a filename is not
passed, the Bloom filter will be created in memory.